# SEQIRmap
 SEQIRmap为论文的代码包，提供了获取数据，模型计算，可视化等功能。所有的计算方法和模型均基于所发表的论文。

## 1. SEQIRmap.get_data(country,t_start_str,t_end_str) 
该函数可获取计算所需要的数据包括每日新增感染人数，每日新增感染人数，累计感染人数，每日疫苗接种率等，数据预处理的方法均采用论文中的方法。 
| 参数 | 说明 | 数据类型 |
| :-----: | :----: | :----: |
| country | 国家的英文名称(首字母应该大写) | str |
| t_start_str | 开始日期,格式为'xxxx-xx-xx'如'2022-01-01' | str | 
| t_end_str | 结束日期,格式为'xxxx-xx-xx'如'2022-01-01' | str |
